@@ -5,12 +5,12 @@
 ;; Author: Feng Shu <tumashu@163.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/posframe
-;; Package-Version: 20251125.846
-;; Package-Revision: d93828bf6c36
+;; Package-Version: 20260121.148
+;; Package-Revision: 2160846ed3be
 ;; Keywords: convenience, tooltip
 ;; Package-Requires: ((emacs "26.1"))
 
-;; This file is not part of GNU Emacs.
+;; This file is part of GNU Emacs.
 
 ;; GNU Emacs is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -236,7 +236,7 @@ The builtin poshandler functions are listed below:
 7.  `posframe-poshandler-frame-bottom-left-corner'
 8.  `posframe-poshandler-frame-bottom-right-corner'
 9.  `posframe-poshandler-window-center'
-10.  `posframe-poshandler-window-top-center'
+10. `posframe-poshandler-window-top-center'
 11. `posframe-poshandler-window-top-left-corner'
 12. `posframe-poshandler-window-top-right-corner'
 13. `posframe-poshandler-window-bottom-center'
@@ -497,8 +497,14 @@ You can use `posframe-delete-all' to delete all posframes."
                        :font-height font-height
                        :font-width font-width
                        :posframe posframe
-                       :posframe-width (frame-pixel-width posframe)
-                       :posframe-height (frame-pixel-height posframe)
+                       :posframe-width
+                       (if width
+                           (* (default-font-width) width)
+                         (frame-pixel-width posframe))
+                       :posframe-height
+                       (if height
+                           (* (default-line-height) height)
+                         (frame-pixel-height posframe))
                        :posframe-buffer buffer
                        :parent-frame parent-frame
                        :parent-frame-width parent-frame-width
@@ -848,8 +854,14 @@ will be removed."
         (max-height (plist-get size-info :max-height))
         (min-width (plist-get size-info :min-width))
         (min-height (plist-get size-info :min-height)))
-    (when height (set-frame-height posframe height))
-    (when width (set-frame-width posframe width))
+    (cond
+     ((and width height)
+      (set-frame-size posframe
+                      (* (default-font-width) width)
+                      (* (default-line-height) height)
+                      t))
+     (height (set-frame-height posframe height))
+     (width (set-frame-width posframe width)))
     (unless (and height width)
       (posframe--fit-frame-to-buffer
        posframe max-height min-height max-width min-width
@@ -950,7 +962,8 @@ This need PARENT-FRAME-WIDTH and PARENT-FRAME-HEIGHT"
                (equal posframe--last-posframe-displayed-size
                       (cons (frame-pixel-width posframe)
                             (frame-pixel-height posframe))))
-    (set-frame-position posframe (car position) (cdr position))
+    (unless (equal (frame-position posframe) position)
+      (set-frame-position posframe (car position) (cdr position)))
     (setq-local posframe--last-posframe-pixel-position position)
     (setq-local posframe--last-parent-frame-size
                 (cons parent-frame-width parent-frame-height))
